==> haskell-snap-server-1.1.1.1-67-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-server
version: 1.1.1.1
id: snap-server-1.1.1.1-56ZqjXU68kw90m5TTeenjR
key: snap-server-1.1.1.1-56ZqjXU68kw90m5TTeenjR
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors  (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.
category: Web, Snap, IO-Streams
abi: 8d8b899e3084a86329d3458578dde5be
exposed: True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger
hidden-modules: Paths_snap_server Control.Concurrent.Extended
                Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
                Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
                Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
                Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
                Snap.Internal.Http.Server.TimeoutManager
                Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux
import-dirs: /usr/lib/ghc-8.6.5/site-local/snap-server-1.1.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/snap-server-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/snap-server-1.1.1.1
hs-libraries: HSsnap-server-1.1.1.1-56ZqjXU68kw90m5TTeenjR
depends:
    attoparsec-0.13.2.3-G0AWAouFPeyAsmzjnpc0yX base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    clock-0.8-H1S1zDefxirImaRbI6ITNv containers-0.6.0.1
    filepath-1.4.2.1 io-streams-1.5.1.0-KUkAVHD2TFGCwHWvDOYzEd
    io-streams-haproxy-1.0.1.0-5tJSe10bmjXBFV9jlKQUr7
    lifted-base-0.2.3.12-6sIyoywK5sSEK6qAF0Ssup mtl-2.2.2
    network-2.8.0.0-1DkaUVvVIsp8sj7KmlE9xl
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    snap-core-1.0.4.0-LYRqE23TMC1C3MMXt682lH text-1.2.3.1 time-1.8.0.2
    unix-2.7.2.2 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html: /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-server-1.1.1.1-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-server
version: 1.1.1.1
id: snap-server-1.1.1.1-AgKHBhdjBhDAVD3TgJAgsy
key: snap-server-1.1.1.1-AgKHBhdjBhDAVD3TgJAgsy
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors  (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.
category: Web, Snap, IO-Streams
abi: 87d98c196bbe00cbd77bd107b46b83c8
exposed: True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger
hidden-modules: Paths_snap_server Control.Concurrent.Extended
                Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
                Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
                Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
                Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
                Snap.Internal.Http.Server.TimeoutManager
                Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux
import-dirs: /usr/lib/ghc-8.6.5/site-local/snap-server-1.1.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/snap-server-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/snap-server-1.1.1.1
hs-libraries: HSsnap-server-1.1.1.1-AgKHBhdjBhDAVD3TgJAgsy
depends:
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    clock-0.8-H1S1zDefxirImaRbI6ITNv containers-0.6.0.1
    filepath-1.4.2.1 io-streams-1.5.1.0-6McI36SMiRy3z1Eb7UmNwA
    io-streams-haproxy-1.0.1.0-6HlCAeCnbJLEOgFFCbkRLb
    lifted-base-0.2.3.12-B4DztZYcWo5FX71P7R1jj6 mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    snap-core-1.0.4.0-CGnmdCcCkZ9DPYiwHGGjZ text-1.2.3.1 time-1.8.0.2
    unix-2.7.2.2 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html: /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
